# == Class: autofs
# The <code>autofs</code> class initialize technical infrastructure for autofs client
#
# === Description
# * This class install appropriate packages and configure autofs service
# * It declares function to add automount
#
# === Requirements
# <code>class concat::setup</code>
#
# === Parameters / Variables
# Not applicable
#
# === Usage
# <code>include autofs</code>
# <code></code>
# <code>autofs_share{ 'temp_infra':</code>
# <code>  path   => 'temp_infra',</code>
# <code>  attr   => 'fstype=nfs,intr',</code>
# <code>  target => 'vxnfs1:/srv/nfs1/temp_infra',</code>
# <code>}</code>
#
# === Authors
# Julien Abbé <julien.abbe@dayotech.fr>
#
# === Copyright
# See LICENSE file in this module root
#
class autofs {

  include concat::setup
  
  concat { '/etc/auto.fs' :
    mode   => '0644',
    owner  => 'root',
    group  => 'root',
    notify => Service['autofs']
  }

  $os_ver = inline_template("<%=operatingsystemrelease.split('.')[0]%>")

  if $os_ver != 6 {
    fail("Error : Can only be applied on validated plateform => RHEL/CentOS 6")
  }

  package { 'autofs':
    ensure  => 'installed',
  }

  file { '/etc/auto.master':
    ensure  => 'present',
    source  => 'puppet:///modules/autofs/auto.master',
    require => Package['autofs'],
    notify  => Service['autofs']
  }

  service { 'autofs':
    enable  => true,
    ensure  => 'running',
    require => File['/etc/auto.master'],
  }

  concat::fragment { 'autofs_header' :
    target  => '/etc/auto.fs',
    order   => 00,
    content => "###FILE MANAGED BY PUPPET, DON'T MOD IT !!\n",
  }

#  autofs_share{ 'temp_infra':
#    path   => 'temp_infra',
#    attr   => 'fstype=nfs,intr',
#    target => 'vxnfs1:/srv/nfs1/temp_infra',
#  } 

}
